==> dde-calendar_5.8.29.orig.tar.xz: dde-calendar-5.8.29/translations/dde-calendar-service_gl_ES.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="gl_ES">
<context>
    <name>JobRemindManager</name>
    <message>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="94"/>
        <source>One day before start</source>
        <translation>Un día antes do comezo</translation>
    </message>
    <message>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="94"/>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="98"/>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="105"/>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="109"/>
        <source>Close</source>
        <comment>button</comment>
        <translation>Pechar</translation>
    </message>
    <message>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="98"/>
        <source>Remind me tomorrow</source>
        <translation>Lembrarme mañá</translation>
    </message>
    <message>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="105"/>
        <source>Remind me later</source>
        <translation>Lembrarme máis tarde</translation>
    </message>
    <message>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="116"/>
        <source>Schedule Reminder</source>
        <translation>Programar recordatorio</translation>
    </message>
    <message>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="236"/>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="245"/>
        <source>%1 to %2</source>
        <translation>%1 a %2</translation>
    </message>
    <message>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="317"/>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="328"/>
        <source>Today</source>
        <translation>Hoxe</translation>
    </message>
    <message>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="320"/>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="331"/>
        <source>Tomorrow</source>
        <translation>Mañá</translation>
    </message>
</context>
</TS>

==> dde-calendar_5.9.5.orig.tar.xz: dde-calendar-5.9.5/translations/dde-calendar-service_gl_ES.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="gl_ES">
<context>
    <name>DAccountDataBase</name>
    <message>
        <source>Work</source>
        <translation>Traballo</translation>
    </message>
    <message>
        <source>Life</source>
        <translation>Persoal</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Outros</translation>
    </message>
</context>
<context>
    <name>DAlarmManager</name>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation>Pechar</translation>
    </message>
    <message>
        <source>One day before start</source>
        <translation>Un día antes do comezo</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation>Lembrarme mañá</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Lembrarme máis tarde</translation>
    </message>
    <message>
        <source>15 mins later</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>1 hour later</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>4 hours later</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>Mañá</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation>Programar recordatorio</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation>%1 a %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Hoxe</translation>
    </message>
</context>
<context>
    <name>JobRemindManager</name>
    <message>
        <source>One day before start</source>
        <translation type="vanished">Un día antes do comezo</translation>
    </message>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation type="vanished">Pechar</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation type="vanished">Lembrarme mañá</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation type="vanished">Lembrarme máis tarde</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation type="vanished">Programar recordatorio</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation type="vanished">%1 a %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation type="vanished">Hoxe</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation type="vanished">Mañá</translation>
    </message>
</context>
</TS>
